﻿using Microsoft.AspNetCore.SignalR;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace Tsi1.Api.SignalR
{
    public class PresenceHub : Hub
    {
        private readonly PresenceTracker _tracker;
        public PresenceHub(PresenceTracker tracker)
        {
            _tracker = tracker;
        }

        public override async Task OnConnectedAsync()
        {
            var userId = int.Parse(Context.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var isOnline = await _tracker.UserConnected(userId, Context.ConnectionId);
            if (isOnline)
                await Clients.Others.SendAsync("UserIsOnline", userId);

            var currentUsers = await _tracker.GetOnlineUsers();
            await Clients.Caller.SendAsync("GetOnlineUsers", currentUsers);
        }

        public override async Task OnDisconnectedAsync(Exception exception)
        {
            var userId = int.Parse(Context.User.Claims.FirstOrDefault(x => x.Type == "Id").Value);

            var isOffline = await _tracker.UserDisconnected(userId, Context.ConnectionId);

            if (isOffline)
                await Clients.Others.SendAsync("UserIsOffline", userId);

            await base.OnDisconnectedAsync(exception);
        }
    }
}
